Displaying 20 results from an estimated 25 matches for "cuid".
Did you mean:
cpuid
2002 Mar 15
4
PATCH: sftp-server logging.
....orig Thu Mar 14 15:00:51 2002
--- sftp-server.c Fri Mar 15 11:57:48 2002
***************
*** 52,57 ****
--- 52,66 ----
/* Version of client */
int version;
+ #ifdef SFTP_LOGGING
+ /* User information. */
+ #define CUNAME cuname ? cuname : "UNKNOWN"
+ struct passwd *upw;
+ uid_t cuid;
+ pid_t ppid;
+ char *cuname;
+ #endif
+
/* portable attibutes, etc. */
typedef struct Stat Stat;
***************
*** 93,98 ****
--- 102,126 ----
return ret;
}
+ #ifdef SFTP_LOGGING
+ char*
+ status_to_logstr(int status)
+ {
+ switch (status) {
+ case SSH2_FX_OK:
+ return &qu...
2008 Sep 23
3
Association error using find since upgrading to Rails 2.1.1
...#39;,
:database => ''my_database,
:username => ''postgres''
)
class Schedule < ActiveRecord::Base
belongs_to :user
end
class User < ActiveRecord::Base
has_many :schedules
end
# This works with AR 2.1.1
s = Schedule.find(:first)
p s.user_id
p s.user.cuid
# This does not with AR 2.1.1 => PGError: ERROR: column "cuid" does
not exist
s = Schedule.find(
:first,
:include => [:user],
:conditions => ["cuid = ?", "foo"] # Also tried user.cuid
)
What obvious bit am I missing?
Thanks,
Dan
--~--~--------...
2001 Jun 20
1
SFTP Logging Redux.
...------
--- sftp-server.c.orig Tue Jun 19 16:32:45 2001
+++ sftp-server.c Wed Jun 20 08:54:03 2001
@@ -52,8 +52,14 @@
/* Version of client */
int version;
-/* portable attibutes, etc. */
+/* User information. */
+#define CUNAME cuname ? cuname : "UNKNOWN"
+struct passwd *upw;
+uid_t cuid;
+pid_t ppid;
+char *cuname;
+/* portable attibutes, etc. */
typedef struct Stat Stat;
struct Stat {
@@ -115,6 +121,28 @@
return flags;
}
+void
+sflags_from_portable(char *psflags, int pflags)
+{
+ if (pflags & SSH2_FXF_READ)
+ *psflags = 'r';
+ psflags++;
+ if (pflags &...
1999 Aug 06
2
Solaris 7 5/99 and samba-2.0.5a (PR#19508)
...pid_t pid;
+ struct passwd *root_pwd = sys_getpwuid((uid_t)0);
+ gid_t root_gid = root_pwd ? root_pwd->pw_gid : (gid_t)0;
read_only = ronly;
@@ -593,7 +596,7 @@
hash_size = sem_ds.sem_nsems-1;
if (!read_only) {
- if (sem_ds.sem_perm.cuid != 0 || sem_ds.sem_perm.cgid != 0) {
+ if (sem_ds.sem_perm.cuid != 0 || sem_ds.sem_perm.cgid !=
root_gid) {
DEBUG(0,("ERROR: root did not create the semaphore\n"));
return NULL;
}
@@ -684,7 +687,7 @@
}...
2007 Sep 09
1
Unexpected input from auth master: CUID
...using postfix(2.4.5) and dovecot(1.0.5), and till now I have been
using postfix deliver agent. Now I have tried to reconfigure postfix to
use the dovecot LDA, but I'm getting some strange error:
Sep 9 18:07:57 hostname deliver(username at domain.tld): BUG: Unexpected
input from auth master: CUID^I5
For IMAP and POP3 my configuration works fine.
I have tried it also with dovecot versions 1.0.4 and 1.0.1, but the
behaviour is the same.
What can be the reason of this? What should I look for to get more
details what can causing this?
I have this line in postfix master file:
dovecot unix...
2007 Sep 10
0
(re: B. Baca) Dovecot] Unexpected input from auth master: CUID
Branislav Baca wrote the following:
Hello,
I'm using postfix(2.4.5) and dovecot(1.0.5), and till now I have been
using postfix deliver agent. Now I have tried to reconfigure postfix to
use the dovecot LDA, but I'm getting some strange error:
Try this:
socket listen {
master {
path = /path/to/run/dovecot/auth-master
mode = 0600
user =
2007 Sep 10
0
(re: B. Baca 2) Dovecot] Unexpected input from auth master: CUID
Also check the top of Authentication processes section:
##
## Authentication processes
##
# Executable location
auth_executable = /path/to/libexec/dovecot/dovecot-auth
-------------- next part --------------
A non-text attachment was scrubbed...
Name: smime.p7s
Type: application/pkcs7-signature
Size: 2447 bytes
Desc: not available
URL:
1999 Aug 14
1
HPUX shared memory creates error (PR#19573)
...pid_t pid;
+ struct passwd *root_pwd = sys_getpwuid((uid_t)0);
+ gid_t root_gid = root_pwd ? root_pwd->pw_gid : (gid_t)0;
read_only = ronly;
@@ -593,8 +595,8 @@
hash_size = sem_ds.sem_nsems-1;
if (!read_only) {
- if (sem_ds.sem_perm.cuid != 0 || sem_ds.sem_perm.cgid != 0) {
- DEBUG(0,("ERROR: root did not create the semaphore\n"));
+ if (sem_ds.sem_perm.cuid != 0 || ((sem_ds.sem_perm.cgid != root_gid) && (sem_ds.sem_perm.cgid != 0))) {
+ DEBUG(0,("ERRO...
2004 Aug 06
0
[PATCH] Configurable privileges and chroot jail
...ivileged user if defined. */
+ drop_privileges();
+
/* Initialize the interpreter (if configured) */
interpreter_init ();
@@ -231,6 +237,80 @@
#endif
}
+void drop_privileges()
+{
+#ifdef _WIN32
+ return;
+#else
+ struct passwd *pwd;
+ uid_t uid, cuid;
+ gid_t gid;
+
+ if (info.icecast_user != 0) {
+ pwd = getpwnam(info.icecast_user);
+ if (!pwd) {
+ write_log (LOG_DEFAULT, "ERROR: icecast_user %s doesn't exist",
+ info.icecast_us...
2004 Dec 09
1
Exim4 authentication patch
...************************************************/
+
+int auth_dovecot_server(auth_instance *ablock, uschar *data)
+{
+ auth_dovecot_options_block *ob =
+ (auth_dovecot_options_block *)(ablock->options_block);
+ struct sockaddr_un sa;
+ char buffer[4096];
+ char *args[8];
+ int nargs, tmp;
+ int cuid = 0, cont = 1, found = 0, fd, ret = DEFER;
+ FILE *f;
+
+ memset(&sa, 0, sizeof(sa));
+ sa.sun_family = AF_UNIX;
+ if (strncpy(sa.sun_path, ob->server_socket, sizeof(sa.sun_path)) < 0) {
+ auth_defer_msg = "authentication socket path too long";
+ return DEFER;
+ }
+
+ auth_def...
2006 Feb 06
0
Webrick, ldap segfault on Linux
...nd without --enable-pthread. Didn''t make a difference
either way.
./app/models/user.rb:64: [BUG] Segmentation fault
ruby 1.8.4 (2005-12-24) [i686-linux]
Aborted
# user.rb (from /app/models)
require "ldap"
require "timeout"
class User < A
...
def self.login(cuid, password)
ldap_server = "ldapt.foo.com"
bool = true
if ENV["RAILS_ENV"].downcase == "production"
ldap_server = "ldap.foo.com"
end
dn = "uid=#{cuid},ou=People,dc=foo,dc=bar,dc=com"
begin
Timeo...
1999 Oct 23
3
semaphores and Solaris 7 8/99
I just installed the 8/99 release of Solaris 7 on three Sun Ultra 10's and
it seems to have broken Samba. I am running Samba 2.0.5a and it works fine
on an Ultra 10 running the 5/99 release of Solaris 7. All of the Ultra 10's
are using the 64 bit kernel. This is the errors that I am getting.
[1999/10/22 21:09:56, 0] locking/shmem_sysv.c:sysv_shm_open(597)
ERROR: root did not create the
2016 Jun 14
3
Upgrade to 2.2.9 breaks sasl auth
...ons.
Now I get these results looking at the inet connection
Version 2.0.19
root at larch:~# telnet 192.168.3.15 12345
Trying 192.168.3.15...
Connected to 192.168.3.15.
Escape character is '^]'.
VERSION 1 1
MECH PLAIN plaintext
MECH LOGIN plaintext
MECH CRAM-MD5 dictionary active
SPID 23223
CUID 1
COOKIE d0b71942d48585303f9ae4681baabf87
DONE
Version 2.2.9
root at larch:~# telnet 192.168.3.112 12345
Trying 192.168.3.112...
Connected to 192.168.3.112.
Escape character is '^]'.
VERSION 1 1
SPID 5300
Seems be something lacking in the response from 2.2.9 that fits the "no
sasl m...
2007 Nov 06
5
textarea fails on rows attribute
Hi,
Camping 1.5.180
Ruby 1.8.6
It looks like Camping is choking on the ''rows'' attribute for input tags:
input(:name => ''cuid'', :type => ''text'', :size => 10, :rows => 3)
That will fail with:
Markaby::InvalidXhtmlError no attribute `rows'' on input elements:
c:/ruby/lib/ruby/gems/1.8/gems/markaby-0.5/lib/markaby/builder.rb:143:in
`tag!''
c:/ruby/lib/ruby/gems/1.8/gems/m...
2014 Jul 30
1
Issue with exim and auth protocol
...same (but with dovecot
2.1.17) where it does work. In that case, dovecot finishes the handshake
before exim starts its handshake. It results in:
exim connects to dovecot auth
dovecot VERSION 1 1
dovecot MECH PLAIN plaintext
dovecot SPID 10905
dovecot CUID 1
dovecot COOKIE d3861d29441f06d962490eab8549fd46
dovecot DONE
exim VERSION 1 0
exim CPID 10619
exim AUTH 1 PLAIN service=smtp secured
rip=82.247.184.53 lip=80.67.179.36 nologin resp=<base64
encoded string>
I don't u...
2006 Apr 21
8
web services and dealing with before_filter
Hi all,
I''ve got a Rails app with a ApplicationController that looks like this:
class ApplicationController < ActionController::Base
before_filter :authorize, :except => :login
def authorize
unless session[:user]
flash[:notice] = "Please log in"
session[:jumpto] = request.parameters
redirect_to :controller =>
2010 Jun 24
2
Work with auth socket
I need to use Dovecot auth socket from my perl script to validate user's
passwords (for jabber server). Is there any information about how to
communicate with dovecot auth socket?
2011 Jun 28
3
Exim and Dovecot2 SASL: 435 Unable to authenticate at present
...cord_recv(7f102023f0c0, 7f1020241e40, 4096)
29279 SMTP<< AUTH LOGIN
29279 dovecot authentication
29279 received: VERSION 1 1
29279 received: MECH PLAIN plaintext
29279 received: MECH LOGIN plaintext
29279 received: MECH APOP private dictionary active
29279 received: SPID 29280
29279 received: CUID 1
29279 received: COOKIE cf735efce15b21bbb10568c4a762017c
29279 SMTP>> 435 Unable to authenticate at present
29279 tls_do_write(7f10202175a0, 39)
29279 gnutls_record_send(SSL, 7f10202175a0, 39)
29279 outbytes=39
29279 LOG: MAIN REJECT
29279 auth_login authenticator failed for (mail.domain.l...
2008 Jan 20
3
Exim Dovecot Authentication Problem
Having a hard time figuring out something that is supposed to be easy.
Tryiong to configure Dovecot so that it provides authentication to Exim
for outgoing smtp. Tried different things and getting
authentication socket protocol error
dovecot_plain:
driver = dovecot
public_name = PLAIN
server_socket = /var/run/dovecot/auth-client
server_set_id = $auth1
auth default {
# Space
2016 Sep 23
2
Broken auth-* sockets.
...me command:
---
# socat - UNIX-CONNECT:/var/dovecot/auth-client
VERSION 1 1
MECH PLAIN plaintext
MECH LOGIN plaintext
MECH CRAM-MD5 dictionary active
MECH DIGEST-MD5 dictionary active mutual-auth
MECH APOP private dictionary active
SPID 535
CUID 880
COOKIE 0311e84ed191fb63334819b1fc3bf2e3
DONE
---
with a different result!!!
The system:
---
uname -a
Linux *** 4.4.0-38-generic #57-Ubuntu SMP Tue Sep 6 15:41:41 UTC 2016
i686 i686 i686 GNU/Linux
---
Doveconf:
---
# dovecot -n
# 2.2.22 (fe789d2): /etc/dovecot/dovecot.conf
# Pigeonhole...